package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.BusinessArticleLike;
import org.apache.ibatis.annotations.Param;

/**
 * 帖子点赞Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-18
 */
public interface BusinessArticleLikeMapper 
{
    /**
     * 查询帖子点赞
     * 
     * @param likeId 帖子点赞主键
     * @return 帖子点赞
     */
    public BusinessArticleLike selectBusinessArticleLikeByLikeId(Long likeId);

    public BusinessArticleLike selectOneByArticleIdUserId(@Param("userId")Long userId,@Param("articleId") Long articleId);
    /**
     * 查询帖子点赞列表
     * 
     * @param businessArticleLike 帖子点赞
     * @return 帖子点赞集合
     */
    public List<BusinessArticleLike> selectBusinessArticleLikeList(BusinessArticleLike businessArticleLike);

    /**
     * 新增帖子点赞
     * 
     * @param businessArticleLike 帖子点赞
     * @return 结果
     */
    public int insertBusinessArticleLike(BusinessArticleLike businessArticleLike);

    /**
     * 修改帖子点赞
     * 
     * @param businessArticleLike 帖子点赞
     * @return 结果
     */
    public int updateBusinessArticleLike(BusinessArticleLike businessArticleLike);

    /**
     * 删除帖子点赞
     * 
     * @param likeId 帖子点赞主键
     * @return 结果
     */
    public int deleteBusinessArticleLikeByLikeId(Long likeId);

    /**
     * 批量删除帖子点赞
     * 
     * @param likeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinessArticleLikeByLikeIds(Long[] likeIds);
}
